==============================
Tasks Foreground
==============================

EstimateZodi
----------------

.. autoclass:: exorad.tasks.foregroundHandler.EstimateZodi
    :members:
    :undoc-members:
    :show-inheritance:


EstimateForeground
------------------

.. autoclass:: exorad.tasks.foregroundHandler.EstimateForeground
    :members:
    :undoc-members:
    :show-inheritance:


EstimateForegrounds
-------------------

.. autoclass:: exorad.tasks.foregroundHandler.EstimateForegrounds
    :members:
    :undoc-members:
    :show-inheritance:
